diff src/window.h @ 1994:73ce9dd21093

Use the term `scroll bar', instead of `scrollbar'. * alloc.c, frame.c, frame.h, indent.c, keyboard.c, keyboard.h, lisp.h, term.c, termhooks.h, window.c, window.h, xdisp.c, xfns.c, xterm.c, xterm.h: Terminology changed.
author Jim Blandy <jimb@redhat.com>
date Tue, 02 Mar 1993 08:22:42 +0000
parents ad692b76edf4
children 480abddc8bdd
line wrap: on
line diff
--- a/src/window.h	Tue Mar 02 08:21:49 1993 +0000
+++ b/src/window.h	Tue Mar 02 08:22:42 1993 +0000
@@ -123,12 +123,12 @@
     Lisp_Object last_modified;
     /* Value of point at that time */
     Lisp_Object last_point;
     /* This window's vertical scrollbar.  This field is only for use
        by the window-system-dependent code which implements the
-       scrollbars; it can store anything it likes here.  If this
-       window is newly created and we haven't displayed a scrollbar in
-       it yet, or if the frame doesn't have any scrollbars, this is nil.  */
-    Lisp_Object vertical_scrollbar;
+       scroll bars; it can store anything it likes here.  If this
+       window is newly created and we haven't displayed a scroll bar in
+       it yet, or if the frame doesn't have any scroll bars, this is nil.  */
+    Lisp_Object vertical_scroll_bar;
 
 /* The rest are currently not used or only half used */
     /* Frame coords of point at that time */
@@ -123,12 +123,12 @@
     /* Value of point at that time */
     Lisp_Object last_point;
-    /* This window's vertical scrollbar.  This field is only for use
+    /* This window's vertical scroll bar.  This field is only for use
        by the window-system-dependent code which implements the